@@ -41,7 +41,8 @@ NODE1 = {'uuid': '66666666-7777-8888-9999-000000000000',
          'properties': {'num_cpu': 4},
          'name': 'fake-node-1',
          'resource_class': 'foo',
-         'extra': {}}
+         'extra': {},
+         'conductor_group': 'in-the-closet-to-the-left'}
 NODE2 = {'uuid': '66666666-7777-8888-9999-111111111111',
          'instance_uuid': '66666666-7777-8888-9999-222222222222',
          'chassis_uuid': 'aaaaaaaa-1111-bbbb-2222-cccccccccccc',
@@ -200,6 +201,13 @@ fake_responses = {
             {"nodes": [NODE1]},
         )
     },
+    '/v1/nodes/?conductor_group=foo':
+    {
+        'GET': (
+            {},
+            {"nodes": [NODE1]},
+        )
+    },
     '/v1/nodes/?chassis_uuid=%s' % NODE2['chassis_uuid']:
     {
         'GET': (
@@ -207,6 +215,13 @@ fake_responses = {
             {"nodes": [NODE2]},
         )
     },
+    '/v1/nodes/?conductor=fake-conductor':
+    {
+        'GET': (
+            {},
+            {"nodes": [NODE2]},
+        )
+    },
     '/v1/nodes/detail?instance_uuid=%s' % NODE2['instance_uuid']:
     {
         'GET': (
@@ -780,6 +795,15 @@ class NodeManagerTest(testtools.TestCase):
         self.assertThat(nodes, HasLength(1))
         self.assertEqual(NODE1['uuid'], getattr(nodes[0], 'uuid'))
 
+    def test_node_list_conductor_group(self):
+        nodes = self.mgr.list(conductor_group='foo')
+        expect = [
+            ('GET', '/v1/nodes/?conductor_group=foo', {}, None),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertThat(nodes, HasLength(1))
+        self.assertEqual(NODE1['uuid'], getattr(nodes[0], 'uuid'))
+
     def test_node_list_chassis(self):
         ch2 = NODE2['chassis_uuid']
         nodes = self.mgr.list(chassis=ch2)
@@ -808,6 +832,15 @@ class NodeManagerTest(testtools.TestCase):
         self.assertThat(nodes, HasLength(1))
         self.assertEqual(NODE2['uuid'], getattr(nodes[0], 'uuid'))
 
+    def test_node_list_with_conductor(self):
+        nodes = self.mgr.list(conductor='fake-conductor')
+        expect = [
+            ('GET', '/v1/nodes/?conductor=fake-conductor', {}, None),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertThat(nodes, HasLength(1))
+        self.assertEqual(NODE2['uuid'], getattr(nodes[0], 'uuid'))
+
     def test_node_list_detail(self):
         nodes = self.mgr.list(detail=True)
         expect = [
@@ -908,6 +941,19 @@ class NodeManagerTest(testtools.TestCase):
         self.assertEqual(expect, self.api.calls)
         self.assertEqual(NEW_DRIVER, node.driver)
 
+    def test_update_with_reset_interfaces(self):
+        patch = {'op': 'replace',
+                 'value': NEW_DRIVER,
+                 'path': '/driver'}
+        node = self.mgr.update(node_id=NODE1['uuid'], patch=patch,
+                               reset_interfaces=True)
+        expect = [
+            ('PATCH', '/v1/nodes/%s' % NODE1['uuid'],
+             {}, patch, {'reset_interfaces': True}),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertEqual(NEW_DRIVER, node.driver)
+
     def test_update_microversion_override(self):
         patch = {'op': 'replace',
                  'value': NEW_DRIVER,
@@ -1342,6 +1388,16 @@ class NodeManagerTest(testtools.TestCase):
         ]
         self.assertEqual(expect, self.api.calls)
 
+    def test_node_set_provision_state_with_configdrive_as_dict(self):
+        target_state = 'active'
+        self.mgr.set_provision_state(NODE1['uuid'], target_state,
+                                     configdrive={'user_data': ''})
+        body = {'target': target_state, 'configdrive': {'user_data': ''}}
+        expect = [
+            ('PUT', '/v1/nodes/%s/states/provision' % NODE1['uuid'], {}, body),
+        ]
+        self.assertEqual(expect, self.api.calls)
+
     def test_node_set_provision_state_with_configdrive_file(self):
         target_state = 'active'
         file_content = b'foo bar cat meow dog bark'
